# Meta Model
### On this page
  * [Overview of the SAP LeanIX Meta Model](https://help.sap.com/docs/leanix/ea/meta-model#overview-of-the-sap-leanix-meta-model)
  * [Layers of the SAP LeanIX Meta Model](https://help.sap.com/docs/leanix/ea/meta-model#layers-of-the-sap-leanix-meta-model)
  * [Fact Sheet Types](https://help.sap.com/docs/leanix/ea/meta-model#fact-sheet-types)
  * [Fact Sheet Subtypes](https://help.sap.com/docs/leanix/ea/meta-model#fact-sheet-subtypes)
  * [Is the SAP LeanIX Meta Model Configurable?](https://help.sap.com/docs/leanix/ea/meta-model#is-the-sap-leanix-meta-model-configurable?)
  * [Are Fact Sheet Subtypes Configurable?](https://help.sap.com/docs/leanix/ea/meta-model#are-fact-sheet-subtypes-configurable?)
  * [Is Moving from the Meta Model v3 to the Meta Model v4 Necessary?](https://help.sap.com/docs/leanix/ea/meta-model#is-moving-from-the-meta-model-v3-to-the-meta-model-v4-necessary?)


Get an overview of the SAP LeanIX meta model and its key concepts.
This page gives you an overview of the core beliefs related to the SAP LeanIX meta model and basic concepts.
**Note**
  * If your workspace is configured by default with meta model v4, refer to our [General Modeling Guidelines](https://help.sap.com/docs/leanix/ea/general-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how the SAP LeanIX meta model works and how to interpret key concepts like fact sheet attributes, tags, hierarchies, parent-child relations, and others.") and the specific [guidelines for each individual fact sheet](https://help.sap.com/docs/leanix/ea/fact-sheet-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD) to understand the best practices for modeling. The "Delta to Meta Model v3" page is not relevant for you.
  * If you are a customer who is using meta model v3 (or individual configurations based on v3): Check the [Delta to Meta Model v3](https://help.sap.com/docs/leanix/ea/delta-to-meta-model-v3?locale=en-US&state=PRODUCTION&version=CLOUD) page if you want to understand what the key differences are. To configure your workspace to align with meta model v4, see [Configure Workspace for Meta Model v4](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to configure your workspace to align with the Meta Model v4.")
